HwVideoCompressPlatform class abstract
- Inheritance
-
- Object
- PlatformInterface
- HwVideoCompressPlatform
- Implementers
Constructors
- HwVideoCompressPlatform()
- Constructs a HwVideoCompressPlatform.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
onProgress
→ Stream<
double> -
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
compressVideo(
String inputPath) → Future< String?> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- instance ↔ HwVideoCompressPlatform
-
The default instance of HwVideoCompressPlatform to use.
getter/setter pair